@@ -11,7 +11,7 @@ use Dancer::Config;
 
 use base 'Dancer::Template::Abstract';
 
-our $VERSION = '0.0024';
+our $VERSION = '0.0025';
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Dancer::Template::TemplateFlute - Template::Flute wrapper for Dancer
 
 =head1 VERSION
 
-Version 0.0024
+Version 0.0025
 
 =head1 DESCRIPTION
 
@@ -136,23 +136,24 @@ sub render ($$$) {
 	
 	if (@forms = $flute->template->forms()) {
 	    if (@forms == 1) {
-		unless ($tokens->{form}) {
-		    die "Missing form parameters for form " . $forms[0]->name;
-		}
-		    
-		for my $name ($forms[0]->iterators) {
-		    if (ref($tokens->{$name}) eq 'ARRAY') {
-			$iter = Template::Flute::Iterator->new($tokens->{$name});
-			$flute->specification->set_iterator($name, $iter);
+		if ($tokens->{form}) {
+		    for my $name ($forms[0]->iterators) {
+			if (ref($tokens->{$name}) eq 'ARRAY') {
+			    $iter = Template::Flute::Iterator->new($tokens->{$name});
+			    $flute->specification->set_iterator($name, $iter);
+			}
+		    }
+
+		    $forms[0]->set_action($tokens->{form}->action());
+		    $tokens->{form}->fields([map {$_->{name}} @{$forms[0]->fields()}]);
+		    $forms[0]->fill($tokens->{form}->fill());
+
+		    if (Dancer::Config::settings->{session}) {
+			$tokens->{form}->to_session;
 		    }
 		}
-
-		$forms[0]->set_action($tokens->{form}->action());
-		$tokens->{form}->fields([map {$_->{name}} @{$forms[0]->fields()}]);
-		$forms[0]->fill($tokens->{form}->fill());
-
-		if (Dancer::Config::settings->{session}) {
-		    $tokens->{form}->to_session;
+		else {
+		    Dancer::Logger::debug('Missing form parameters for form ' . $forms[0]->name);
 		}
 	    }
 	    else {
